@@ -118,9 +118,6 @@ static gboolean gpcap_conduits_popup (GtkTreeView *treeview, GdkEventButton *eve
 static void gpcap_conduits_selection_changed (GtkTreeSelection *selection, gpointer user_data);
 
 static void gpcap_cap_try (GtkWidget *widget, gpointer user_data);
-static void gpcap_cap_revert (GtkWidget *widget, gpointer user_data);
-static void gpcap_cap_ok (GtkWidget *widget, gpointer user_data);
-static void gpcap_cap_cancel (GtkWidget *widget, gpointer user_data);
 
 static void gpcap_changed (GtkWidget *widget, gpointer user_data);
 
@@ -410,7 +407,7 @@ gnome_pilot_capplet_create_pilots_treeview (char *name, char *string1, char *str
 						     renderer, "text", 3, NULL);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
-	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), TRUE);
 
 	gtk_container_add (GTK_CONTAINER (scrolled), treeview);
@@ -694,13 +691,6 @@ gpcap_set_changed_state (GnomePilotCapplet *gpcap)
 	priv = gpcap->priv;
 
 	gpcap_cap_try (NULL, gpcap);
-
-#if 0
-	if (priv->parent == NULL)
-		return;
-	
-	capplet_widget_state_changed (CAPPLET_WIDGET (priv->parent), TRUE);
-#endif
 }
 
 static void
@@ -755,7 +745,7 @@ gpcap_pilots_add (GtkWidget *widget, gpointer user_data)
 	pilot = get_default_pilot (priv->state);
 	
 	dlg = gnome_pilot_pdialog_new (priv->gpc, priv->state, pilot);
-	res = gnome_pilot_pdialog_run_and_close (GNOME_PILOT_PDIALOG (dlg));
+	res = gnome_pilot_pdialog_run_and_close (GNOME_PILOT_PDIALOG (dlg), GTK_WINDOW (gpcap));
 
 	if (!res) {
 		g_free (pilot);
@@ -789,7 +779,7 @@ gpcap_pilots_edit (GtkWidget *widget, gpointer user_data)
 	pilot = get_current_pilot (gpcap, &iter);
 	
 	dlg = gnome_pilot_pdialog_new (priv->gpc, priv->state, pilot);
-	res = gnome_pilot_pdialog_run_and_close (GNOME_PILOT_PDIALOG (dlg));
+	res = gnome_pilot_pdialog_run_and_close (GNOME_PILOT_PDIALOG (dlg), GTK_WINDOW (gpcap));
  
 	if (res) {
 		gtk_list_store_set (GTK_LIST_STORE (priv->pilots_model), &iter,
@@ -916,7 +906,7 @@ gpcap_devices_add (GtkWidget *widget, gpointer user_data)
 	device = get_default_device (priv->state);
 	
 	dlg = gnome_pilot_ddialog_new (device);
-	res = gnome_pilot_ddialog_run_and_close (GNOME_PILOT_DDIALOG (dlg));
+	res = gnome_pilot_ddialog_run_and_close (GNOME_PILOT_DDIALOG (dlg), GTK_WINDOW (gpcap));
 
 	if (!res) {
 		g_free (device);
@@ -947,7 +937,7 @@ gpcap_devices_edit (GtkWidget *widget, gpointer user_data)
 	device = get_current_device (gpcap, &iter);
 
 	dlg = gnome_pilot_ddialog_new (device);
-	res = gnome_pilot_ddialog_run_and_close (GNOME_PILOT_DDIALOG (dlg));
+	res = gnome_pilot_ddialog_run_and_close (GNOME_PILOT_DDIALOG (dlg), GTK_WINDOW (gpcap));
  
 	if (res) {
 		gtk_list_store_set (GTK_LIST_STORE (priv->devices_model), &iter,
@@ -1107,17 +1097,10 @@ gpcap_conduits_enable (GtkWidget *widget, gpointer user_data)
 			    1, display_sync_type_name (state->enabled, state->sync_type),
 			    -1);
 
-	//	check_conduits_buttons (gpcap);
+	check_conduits_buttons (gpcap);
 	gpcap_set_changed_state (gpcap);
 
-	/* XXX we can't do this here because gtk-2.0 loses the
-	   selection (and therefore there's no selected conduit) in
-	   the call to gtk_list_store_set above.  I've tried wrapping
-	   this area with path's/row references in order to keep a
-	   reference to the right row, then reselect after the _set
-	   call, but this doesn't work either.
-
-	   gpcap_conduits_settings (widget, user_data);*/
+	gpcap_conduits_settings (widget, user_data);
 }
 
 static void 
@@ -1141,7 +1124,7 @@ gpcap_conduits_disable (GtkWidget *widget, gpointer user_data)
 			    1, display_sync_type_name (FALSE, GnomePilotConduitSyncTypeNotSet),
 			    -1);
 
-	//	check_conduits_buttons (gpcap);
+	check_conduits_buttons (gpcap);
 	gpcap_set_changed_state (gpcap);
 }
 
@@ -1173,7 +1156,7 @@ gpcap_conduits_settings (GtkWidget *widget, gpointer user_data)
 	}
 	
 	if (state->settings_widget2 != NULL) {
-		if (gnome_pilot_cdialog_run_and_close (GNOME_PILOT_CDIALOG (state->settings_widget2))) {
+		if (gnome_pilot_cdialog_run_and_close (GNOME_PILOT_CDIALOG (state->settings_widget2), GTK_WINDOW (gpcap))) {
 			/* pressed ok */
 			state->sync_type = gnome_pilot_cdialog_sync_type (GNOME_PILOT_CDIALOG (state->settings_widget2));
 			state->first_sync_type = gnome_pilot_cdialog_first_sync_type (GNOME_PILOT_CDIALOG (state->settings_widget2));
@@ -1321,8 +1304,6 @@ gpcap_cap_try (GtkWidget *widget, gpointer user_data)
 	}
 
 	g_hash_table_foreach (priv->conduits, conduit_try_foreach, NULL);
-	fill_conduit_treeview (gpcap);
-	fill_pilots_menu (gpcap);
 	
 	save_config_and_restart (priv->gpc, priv->state);
 }
@@ -1359,36 +1340,6 @@ conduit_revert_foreach (gpointer key, gpointer value, gpointer func)
 	}
 }
 
-static void
-gpcap_cap_revert (GtkWidget *widget, gpointer user_data)
-{
-	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (user_data);
-	GnomePilotCappletPrivate *priv;
-	
-	priv = gpcap->priv;
-
-	g_hash_table_foreach (priv->conduits, conduit_revert_foreach, gpcap);
-	fill_conduit_treeview (gpcap);
-
-	save_config_and_restart (priv->gpc, priv->orig_state);
-	freePilotState (priv->state);
-	priv->state = dupPilotState (priv->orig_state);
-	
-	fill_widgets (gpcap);
-}
-
-static void 
-gpcap_cap_ok (GtkWidget *widget, gpointer user_data)
-{
-	gpcap_cap_try (widget, user_data);
-}
-
-static void 
-gpcap_cap_cancel (GtkWidget *widget, gpointer user_data)
-{
-	gpcap_cap_revert (widget, user_data);
-}
-
 static void
 gpcap_changed (GtkWidget *widget, gpointer user_data)
 {
