@@ -211,7 +211,7 @@ get_client_id(const GNOME_Pilot_Client cb)
 		
 		client_id = CORBA_ORB_object_to_string(orb,cb,&ev);
 		if(ev._major != CORBA_NO_EXCEPTION) {
-			LOG("unable to resolve IOR for client");
+			LOG(("unable to resolve IOR for client"));
 			LOGEXN (ev);
 			CORBA_exception_free(&ev);
 			return NULL;
@@ -254,7 +254,7 @@ gpilotd_corba_pause_notify_monitor (gchar* key,
 
 	if (ev._major != CORBA_NO_EXCEPTION) {
 		char *client_id = get_client_id (cb);
-		g_message ("corba: monitor %.20s dead", client_id);
+		g_message ("corba: monitor %.20s dead", client_id ? client_id : "<unknown>");
 		CORBA_exception_free (&ev);
 		CORBA_free (client_id);
 	}	
@@ -310,12 +310,12 @@ gpilotd_corba_request_install(GNOME_Pilot_Daemon obj,
 	
 	GET_AND_CHECK_CLIENT_ID(client_id,cb,0);
 
-	LOG("corba: request_install(pilot_name=%s (%d),filename=%s,survival=%d,timeout=%d)",
+	LOG(("corba: request_install(pilot_name=%s (%d),filename=%s,survival=%d,timeout=%d)",
 	    pilot_name,
 	    pilot_id_from_name(pilot_name,orb_context->gpilotd_context),
 	    filename,
 	    survival,
-	    timeout);
+	    timeout));
 
 	req.type = GREQ_INSTALL;
 	req.pilot_id = pilot_id_from_name(pilot_name,orb_context->gpilotd_context);
@@ -365,12 +365,12 @@ gpilotd_corba_request_restore(GNOME_Pilot_Daemon obj,
 	/* FIXME: should be a generic / remover */
 	if (directory[strlen(directory)-1]=='/')
 		directory[strlen(directory)-1]=0;
-	LOG("corba: request_restore(pilot_name=%s (%d), directory=%s,survival=%d,timeout=%d)",
+	LOG(("corba: request_restore(pilot_name=%s (%d), directory=%s,survival=%d,timeout=%d)",
 	    pilot_name,
 	    pilot_id_from_name(pilot_name,orb_context->gpilotd_context),
 	    directory,
 	    survival,
-	    timeout);
+	    timeout));
 
 	req.type = GREQ_RESTORE;
 	req.pilot_id = pilot_id_from_name(pilot_name,orb_context->gpilotd_context);
@@ -419,10 +419,10 @@ gpilotd_corba_request_conduit(GNOME_Pilot_Daemon _obj,
 	
 	GET_AND_CHECK_CLIENT_ID(client_id,cb,0);
   
-	LOG("corba: request_conduit(pilot=%s (%d), conduit=%s)",
+	LOG(("corba: request_conduit(pilot=%s (%d), conduit=%s)",
 	    pilot_name,
 	    pilot_id_from_name(pilot_name,orb_context->gpilotd_context),
-	    conduit_name);
+	    conduit_name));
 	req.pilot_id = pilot_id_from_name(pilot_name,orb_context->gpilotd_context);
 
 	if(req.pilot_id==0) {
@@ -479,8 +479,8 @@ gpilotd_corba_get_user_info(GNOME_Pilot_Daemon obj,
 
 	GET_AND_CHECK_CLIENT_ID(client_id,cb,0);
 
-	LOG("corba: get_user_info(cradle=%s,survival=%d,timeout=%d)",
-	    cradle,survival,timeout);
+	LOG(("corba: get_user_info(cradle=%s,survival=%d,timeout=%d)",
+	    cradle,survival,timeout));
 	/* FIXME: check for cradle existance, throw exn if not */
 	req.type = GREQ_GET_USERINFO;
 	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
@@ -506,8 +506,8 @@ gpilotd_corba_get_system_info(GNOME_Pilot_Daemon obj,
 	gchar *client_id;
 	GET_AND_CHECK_CLIENT_ID(client_id,cb,0);
 	
-	LOG("corba: get_system_info(cradle=%s,survival=%d,timeout=%d)",
-	    cradle ,survival,timeout);
+	LOG(("corba: get_system_info(cradle=%s,survival=%d,timeout=%d)",
+	    cradle ,survival,timeout));
 	
 	req.type = GREQ_GET_SYSINFO;
 	req.pilot_id = 0;
@@ -535,12 +535,12 @@ gpilotd_corba_set_user_info(GNOME_Pilot_Daemon obj,
 
 	GET_AND_CHECK_CLIENT_ID(client_id,cb,0);
 
-	LOG("corba: set_user_info(cradle=%s,survival=%d,timeout=%d",
-	    cradle,survival,timeout);
-	LOG("corba:               device = %s,",cradle);
-	LOG("corba:               user_id = %d,",user->userID);
-	LOG("corba:               user    = %s)",user->username);
-	/*LOG("corba:               password= %s)",user->password);*/
+	LOG(("corba: set_user_info(cradle=%s,survival=%d,timeout=%d",
+	    cradle,survival,timeout));
+	LOG(("corba:               device = %s,",cradle));
+	LOG(("corba:               user_id = %d,",user->userID));
+	LOG(("corba:               user    = %s)",user->username));
+	/*LOG(("corba:               password= %s)",user->password);*/
 	/* FIXME: check for cradle existance, throw exn if not */
 
 	result = gpc_queue_store_set_userinfo_request (survival==GNOME_Pilot_PERSISTENT?0:timeout,
@@ -570,13 +570,13 @@ gpilotd_corba_set_user_info_if_not_set(GNOME_Pilot_Daemon obj,
 	gchar *client_id;
 	GET_AND_CHECK_CLIENT_ID(client_id,cb,0);
 
-	LOG("corba: set_user_info_if_not_set(cradle=%s,survival=%d,timeout=%d",
-	    cradle,survival,timeout);
-	LOG("corba:               device = %s,",cradle);
-	LOG("corba:               client_id = %.20s...,",client_id);
-	LOG("corba:               user_id = %d,",user->userID);
-	LOG("corba:               user    = %s)",user->username);
-	/*LOG("corba:               password= %s)",user->password);*/
+	LOG(("corba: set_user_info_if_not_set(cradle=%s,survival=%d,timeout=%d",
+	    cradle,survival,timeout));
+	LOG(("corba:               device = %s,",cradle));
+	LOG(("corba:               client_id = %.20s...,",client_id));
+	LOG(("corba:               user_id = %d,",user->userID));
+	LOG(("corba:               user    = %s)",user->username));
+	/*LOG(("corba:               password= %s)",user->password));*/
 
 	/* FIXME: check for cradle existance, throw exn if not */
 
@@ -614,25 +614,25 @@ gpilotd_corba_monitor_on(GNOME_Pilot_Daemon obj,
 		CORBA_exception_init(&my_ev);
 		tmp_client_id = CORBA_ORB_object_to_string(orb,cb,&my_ev);
 		if(my_ev._major != CORBA_NO_EXCEPTION) {
-			LOG("*** Client appears to be disconnected...");
+			LOG(("*** Client appears to be disconnected..."));
 			LOGEXN (my_ev);
 		} else {
-			LOG("Client seems ok");
-		}
-		tmpcb = CORBA_ORB_string_to_object(orb,(CORBA_char*)tmp_client_id,&my_ev); 
-		if(my_ev._major != CORBA_NO_EXCEPTION) {
-			LOG("**** Client appears to be disconnected...");
-			LOGEXN (my_ev);
-			g_assert_not_reached();
-		} else {
-			LOG("Client seems ok");
+			LOG(("Client seems ok"));
+			tmpcb = CORBA_ORB_string_to_object(orb,(CORBA_char*)tmp_client_id,&my_ev); 
+			if(my_ev._major != CORBA_NO_EXCEPTION) {
+				LOG(("**** Client appears to be disconnected..."));
+				LOGEXN (my_ev);
+				g_assert_not_reached();
+			} else {
+				LOG(("Client seems ok"));
+			}
 		}
 	}
 #endif
 
 	GET_AND_CHECK_CLIENT_ID_VOID(client_id,cb);
 
-	LOG("monitor_on(pilot_name=\"%s\",client_id = %.20s...)",pilot_name,client_id);
+	LOG(("monitor_on(pilot_name=\"%s\",client_id = %.20s...)",pilot_name,client_id));
 
 	if(pilot_id_from_name(pilot_name,orb_context->gpilotd_context)==0) {
 		g_free(client_id);
@@ -688,7 +688,7 @@ monitor_off_helper_2(const gchar *pilot,
 	g_assert(pilot!=NULL);
 	g_assert(client_id!=NULL);
 
-	LOG("removing monitor on %s for %.10s",pilot,client_id);
+	LOG(("removing monitor on %s for %.10s",pilot,client_id));
 	notifications = g_hash_table_lookup(orb_context->notifications,pilot);
 	if(notifications==NULL) return;
 
@@ -777,15 +777,15 @@ monitor_off_helper(const gchar *pilot,
 		} else {
 			GSList *e;
 			/* This really shouldn't happen, dump list for debug purposes */
-			LOG("Could not find any link for %s",pilot);
+			LOG(("Could not find any link for %s",pilot));
 			for(e=*pilots;e;e = g_slist_next(e)) {
-				LOG("pilots slist dump: %s",
-				    e->data==NULL?"(null)":(char*)e->data);
+				LOG(("pilots slist dump: %s",
+				    e->data==NULL?"(null)":(char*)e->data));
 			}			
 		}
 		
 	} else {
-		LOG("couldn't find any monitor for %.10s",client_id);
+		LOG(("couldn't find any monitor for %.10s",client_id));
 	}
 	
 
@@ -805,7 +805,7 @@ gpilotd_corba_monitor_off(GNOME_Pilot_Daemon obj,
 
 	GET_AND_CHECK_CLIENT_ID_VOID(client_id,cb);
 
-	LOG("monitor_off(pilot_name=\"%.10s\", client_id = %.20s...)",pilot_name,client_id);
+	LOG(("monitor_off(pilot_name=\"%.10s\", client_id = %.20s...)",pilot_name,client_id));
 	if(pilot_id_from_name(pilot_name,orb_context->gpilotd_context)==0) {
 		g_free(client_id);
 		gpthrow_no_val_with_settings(UnknownPilot,exn,exn->pilotId = CORBA_string_dup(pilot_name));
@@ -903,8 +903,8 @@ gpilotd_corba_notify_on(GNOME_Pilot_Daemon obj,
 			event_type = g_strdup("USERINFO_SENT"); break;
 		default: g_assert_not_reached(); break;
 		}
-		LOG("corba: notify_on(event_type=%s,callback=%.20s...)",
-		    event_type,client_id);
+		LOG(("corba: notify_on(event_type=%s,callback=%.20s...)",
+		    event_type,client_id));
 		g_free(event_type);
 	}
 
@@ -952,8 +952,8 @@ gpilotd_corba_notify_off(GNOME_Pilot_Daemon obj,
 			event_type = g_strdup("USERINFO_SENT"); break;
 		default: g_assert_not_reached(); break;
 		}
-		LOG("corba: notify_off(event_type=%s,callback=%.20s...)",
-		    event_type,client_id);
+		LOG(("corba: notify_off(event_type=%s,callback=%.20s...)",
+		    event_type,client_id));
 		g_free(event_type);
 	}
 
@@ -978,7 +978,7 @@ gpilotd_corba_get_users(GNOME_Pilot_Daemon obj,
 			CORBA_Environment *ev) 
 {
 
-	LOG("corba: get_users()");
+	LOG(("corba: get_users()"));
 
 	/* FIXME: this isn't complete, it only gives one user, and
 	   doesn't make any NULL checks... */
@@ -999,7 +999,7 @@ gpilotd_corba_get_cradles(GNOME_Pilot_Daemon obj,
 			  CORBA_Environment *ev) 
 {
 
-	LOG("corba: get_cradles(...)");
+	LOG(("corba: get_cradles(...)"));
 
 	if(g_list_length(orb_context->gpilotd_context->devices)>0) {
 		GNOME_Pilot_StringSequence *cradles;
@@ -1024,7 +1024,7 @@ gpilotd_corba_get_pilots(GNOME_Pilot_Daemon obj,
 			 CORBA_Environment *ev) 
 {
 
-	LOG("corba: get_pilots(...)");
+	LOG(("corba: get_pilots(...)"));
 
 	if(g_list_length(orb_context->gpilotd_context->pilots)>0) {
 		GNOME_Pilot_StringSequence *pilots;
@@ -1049,7 +1049,7 @@ gpilotd_corba_get_pilot_ids(GNOME_Pilot_Daemon obj,
 			    CORBA_Environment *ev) 
 {
 
-	LOG("corba: get_pilot_ids(...)");
+	LOG(("corba: get_pilot_ids(...)"));
 
 	if(g_list_length(orb_context->gpilotd_context->pilots)>0) {
 		GNOME_Pilot_LongSequence *pilots;
@@ -1075,13 +1075,13 @@ gpilotd_corba_get_pilots_by_name(GNOME_Pilot_Daemon obj,
 {
 	int cnt;
 
-	LOG("corba: get_pilots_by_name(%s)",user);
+	LOG(("corba: get_pilots_by_name(%s)",user));
 
 	/* FIXME: this could probably be prettyfied with some _foreach thingies... */
 	if(g_list_length(orb_context->gpilotd_context->pilots)>0) {
 		GNOME_Pilot_StringSequence *pilots;
 		int i;
-		LOG("g_list_length(orb_context->gpilotd_context->pilots) = %d",g_list_length(orb_context->gpilotd_context->pilots));
+		LOG(("g_list_length(orb_context->gpilotd_context->pilots) = %d",g_list_length(orb_context->gpilotd_context->pilots)));
 
 		/* first count the number of pilots to cp */
 		cnt=0;
@@ -1089,12 +1089,12 @@ gpilotd_corba_get_pilots_by_name(GNOME_Pilot_Daemon obj,
 		for(i=0;i<g_list_length(orb_context->gpilotd_context->pilots);i++) {
 			if(strcmp(GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->pilot_username,
 				  user)==0) {
-				LOG("match on %s",GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->name);
+				LOG(("match on %s",GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->name));
 				cnt++;
 			}
 		}
 		if(cnt==0) {
-			LOG("no matches on %s",user);
+			LOG(("no matches on %s",user));
 			return empty_StringSequence(); 
 		}
 
@@ -1124,7 +1124,7 @@ gpilotd_corba_get_pilots_by_login(GNOME_Pilot_Daemon obj,
 	struct passwd *pwdent;
 	GNOME_Pilot_StringSequence *pilots;
 
-	LOG("corba: get_pilots_by_login(%s)",uid);
+	LOG(("corba: get_pilots_by_login(%s)",uid));
 
 	/* find the pwdent matching the login */
 	username = NULL;
@@ -1142,7 +1142,7 @@ gpilotd_corba_get_pilots_by_login(GNOME_Pilot_Daemon obj,
 
 	/* no luck ? */
 	if(!username) {
-		LOG("no realname for %s",uid);
+		LOG(("no realname for %s",uid));
 		return empty_StringSequence();
 	}
 
@@ -1161,7 +1161,7 @@ gpilotd_corba_get_user_name_by_pilot(GNOME_Pilot_Daemon obj,
 #ifdef __GNUC__
 #warning gpilotd_corba_get_user_name_by_pilot not implemented
 #endif
-	LOG("corba: FIXME %s:%d get_user_name_by_pilot", __FILE__, __LINE__);
+	LOG(("corba: FIXME %s:%d get_user_name_by_pilot", __FILE__, __LINE__));
 
 	/* FIXME: not implemented yet */
 	return CORBA_string_dup ("Foo Bar");
@@ -1175,7 +1175,7 @@ gpilotd_corba_get_user_login_by_pilot(GNOME_Pilot_Daemon obj,
 #ifdef __GNUC__
 #warning gpilotd_corba_get_user_login_by_pilot not implemented
 #endif
-	LOG("corba: FIXME %s:%d get_user_login_by_pilot", __FILE__, __LINE__);
+	LOG(("corba: FIXME %s:%d get_user_login_by_pilot", __FILE__, __LINE__));
 
 	/* FIXME: not implemented yet */
 	return CORBA_string_dup ("foo");
@@ -1186,7 +1186,7 @@ gpilotd_get_pilot_base_dir(PortableServer_Servant _servant,
 		     CORBA_char * pilot_name, 
 		     CORBA_Environment * ev) {
 	int i;
-	LOG("corba: get_pilot_base_dir(id=%s)",pilot_name);
+	LOG(("corba: get_pilot_base_dir(id=%s)",pilot_name));
 	
 
 	/* FIXME: this could probably be prettyfied with some _foreach thingies... */
@@ -1195,7 +1195,7 @@ gpilotd_get_pilot_base_dir(PortableServer_Servant _servant,
 		for(i=0;i<g_list_length(orb_context->gpilotd_context->pilots);i++) {
 			if(strcmp(GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->name,
 				  pilot_name)==0) {
-				LOG("match on %s",GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->name);
+				LOG(("match on %s",GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->name));
 				if(GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->sync_options.basedir!=NULL) {
 					return CORBA_string_dup(GPILOT_PILOT(g_list_nth(orb_context->gpilotd_context->pilots,i)->data)->sync_options.basedir);
 				} else {
@@ -1203,7 +1203,7 @@ gpilotd_get_pilot_base_dir(PortableServer_Servant _servant,
 				}
 			}
 		}
-		LOG("no matches on %s",pilot_name);
+		LOG(("no matches on %s",pilot_name));
 		return CORBA_string_dup("");
 	} else 
 		return CORBA_string_dup("");
@@ -1213,7 +1213,7 @@ static CORBA_long
 gpilotd_get_pilot_id_from_name(PortableServer_Servant _servant, 
 			       CORBA_char * pilot_name, 
 			       CORBA_Environment * ev) {
-	LOG("corba: get_user_pilot_id_from_name");
+	LOG(("corba: get_user_pilot_id_from_name"));
 
 	return pilot_id_from_name(pilot_name,orb_context->gpilotd_context);
 }
@@ -1224,7 +1224,7 @@ gpilotd_get_pilot_name_from_id(PortableServer_Servant _servant,
 			       CORBA_Environment * ev) {
 	gchar *tmp;
 	CORBA_char *retval;
-	LOG("corba: get_pilot_name_from_id(id=%d)",pilot_name);
+	LOG(("corba: get_pilot_name_from_id(id=%d)",pilot_name));
 
 	tmp = pilot_name_from_id(pilot_name,orb_context->gpilotd_context);
 	retval =  CORBA_string_dup(tmp);
@@ -1241,7 +1241,7 @@ gpilotd_corba_get_databases_from_cache(GNOME_Pilot_Daemon obj,
 	char **databases,*pfx;
 	int num_bases;
 	guint32 pilot_id;
-	LOG("corba: get_databases_from_cache(...)");
+	LOG(("corba: get_databases_from_cache(...)"));
 
 	pilot_id = pilot_id_from_name(pilot_name,
 				      orb_context->gpilotd_context);
@@ -1416,7 +1416,7 @@ orbed_notify_multi_purpose_foreach(gchar *IOR,
 
 	cb = CORBA_ORB_string_to_object(orb,(CORBA_char*)IOR,&ev);
 	if(ev._major != CORBA_NO_EXCEPTION) {
-		LOG("Client appears to be disconnected...");
+		LOG(("Client appears to be disconnected..."));
 		g_warning ("%s:%d Exception: %s\n",
 			   __FILE__,__LINE__, CORBA_exception_id (&ev));
 		CORBA_exception_free(&ev);
@@ -1482,7 +1482,7 @@ orbed_notify_multi_purpose_foreach(gchar *IOR,
 			break;
 		}
 		if(ev._major != CORBA_NO_EXCEPTION) {
-			LOG("Client appears to be disconnected...");
+			LOG(("Client appears to be disconnected..."));
 			LOGEXN (ev);
 			CORBA_exception_free(&ev);
 			carrier->purge_list = g_slist_prepend(carrier->purge_list,
@@ -1519,8 +1519,8 @@ orbed_notify_connect(const gchar *pilot_id,
 	carrier.purge_list = NULL;
 	carrier.action = CALL_CONNECT;
 #ifdef DEBUG_CODE
-	LOG("corba: orbed_notify_user, notifications->connect.size = %d, id = %s",
-	    g_slist_length(notifications->connect),pilot_id);
+	LOG(("corba: orbed_notify_user, notifications->connect.size = %d, id = %s",
+	    g_slist_length(notifications->connect),pilot_id));
 #endif
 	g_slist_foreach(notifications->connect,
 			(GFunc)orbed_notify_multi_purpose_foreach,
@@ -1551,8 +1551,8 @@ orbed_notify_disconnect(const gchar *pilot_id)
 	carrier.purge_list = NULL;
 	carrier.action = CALL_DISCONNECT;
 #ifdef DEBUG_CODE
-	LOG("corba: orbed_notify_user, notifications->disconnect.size = %d, id = %s",
-	    g_slist_length(notifications->disconnect),pilot_id);
+	LOG(("corba: orbed_notify_user, notifications->disconnect.size = %d, id = %s",
+	    g_slist_length(notifications->disconnect),pilot_id));
 #endif
 	g_slist_foreach(notifications->disconnect,
 			(GFunc)orbed_notify_multi_purpose_foreach,
@@ -1574,18 +1574,18 @@ orbed_notify_completion(GPilotRequest **req)
 	GNOME_Pilot_Client cb;
 	gchar *pilot_name;
 
-	LOG("orbed_notify_completion(...)");
+	LOG(("orbed_notify_completion(...)"));
 
 	g_return_if_fail(req!=NULL);
 	g_return_if_fail(*req!=NULL);
 
 	/* If there is no client to notify, just purge request and return */
 	if((*req)->client_id==NULL) {
-		LOG("%s: no client_id in request",__PRETTY_FUNCTION__);
+		LOG(("%s: no client_id in request",G_GNUC_PRETTY_FUNCTION));
 		gpc_queue_purge_request(req);
 		return;
 	}
-	LOG("%s: client_id = %.20s",__PRETTY_FUNCTION__,(*req)->client_id);
+	LOG(("%s: client_id = %.20s",G_GNUC_PRETTY_FUNCTION,(*req)->client_id));
 
 	/* check the client id is a IOR */
 	g_return_if_fail(strncmp((*req)->client_id,"IOR:",4)==0);
@@ -1596,7 +1596,7 @@ orbed_notify_completion(GPilotRequest **req)
 	/* get the ior, if it fails, print exception and purge request */
 	cb = CORBA_ORB_string_to_object(orb,(CORBA_char*)(*req)->client_id,&ev);
 	if(ev._major != CORBA_NO_EXCEPTION) {
-		LOG("unable to resolve object for IOR");
+		LOG(("unable to resolve object for IOR"));
 		LOGEXN (ev);
 		CORBA_exception_free(&ev);
 		/* FIXME: This purges monitors for the client.
